# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/comments/v1/comments_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-strmprivacy/api/comments/v1/comments_v1.proto\x12\x1bstrmprivacy.api.comments.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"`\n\x14\x43reateCommentRequest\x12H\n\x07\x63omment\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.CommentB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x07\x63omment\"W\n\x15\x43reateCommentResponse\x12>\n\x07\x63omment\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.CommentR\x07\x63omment\"\xa3\x01\n\x13ListCommentsRequest\x12P\n\nentity_ref\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.GenericRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tentityRef\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x80\x01\n\x14ListCommentsResponse\x12@\n\x08\x63omments\x18\x01 \x03(\x0b\x32$.strmprivacy.api.entities.v1.CommentR\x08\x63omments\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"B\n\x14\x44\x65leteCommentRequest\x12*\n\ncomment_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x00\xb0\x01\x01R\tcommentId\"\x17\n\x15\x44\x65leteCommentResponse2\xf6\x02\n\x0f\x43ommentsService\x12v\n\rCreateComment\x12\x31.strmprivacy.api.comments.v1.CreateCommentRequest\x1a\x32.strmprivacy.api.comments.v1.CreateCommentResponse\x12s\n\x0cListComments\x12\x30.strmprivacy.api.comments.v1.ListCommentsRequest\x1a\x31.strmprivacy.api.comments.v1.ListCommentsResponse\x12v\n\rDeleteComment\x12\x31.strmprivacy.api.comments.v1.DeleteCommentRequest\x1a\x32.strmprivacy.api.comments.v1.DeleteCommentResponseBi\n\x1eio.strmprivacy.api.comments.v1P\x01ZEgithub.com/strmprivacy/api-definitions-go/v3/api/comments/v1;commentsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.comments.v1.comments_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036io.strmprivacy.api.comments.v1P\001ZEgithub.com/strmprivacy/api-definitions-go/v3/api/comments/v1;comments'
  _CREATECOMMENTREQUEST.fields_by_name['comment']._options = None
  _CREATECOMMENTREQUEST.fields_by_name['comment']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTCOMMENTSREQUEST.fields_by_name['entity_ref']._options = None
  _LISTCOMMENTSREQUEST.fields_by_name['entity_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETECOMMENTREQUEST.fields_by_name['comment_id']._options = None
  _DELETECOMMENTREQUEST.fields_by_name['comment_id']._serialized_options = b'\372B\010r\006\320\001\000\260\001\001'
  _CREATECOMMENTREQUEST._serialized_start=150
  _CREATECOMMENTREQUEST._serialized_end=246
  _CREATECOMMENTRESPONSE._serialized_start=248
  _CREATECOMMENTRESPONSE._serialized_end=335
  _LISTCOMMENTSREQUEST._serialized_start=338
  _LISTCOMMENTSREQUEST._serialized_end=501
  _LISTCOMMENTSRESPONSE._serialized_start=504
  _LISTCOMMENTSRESPONSE._serialized_end=632
  _DELETECOMMENTREQUEST._serialized_start=634
  _DELETECOMMENTREQUEST._serialized_end=700
  _DELETECOMMENTRESPONSE._serialized_start=702
  _DELETECOMMENTRESPONSE._serialized_end=725
  _COMMENTSSERVICE._serialized_start=728
  _COMMENTSSERVICE._serialized_end=1102
# @@protoc_insertion_point(module_scope)
