# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/categories/v1alpha/categories_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.paging.v1alpha import paging_v1alpha_pb2 as strmprivacy_dot_api_dot_paging_dot_v1alpha_dot_paging__v1alpha__pb2
from validate import validate_pb2 as validate_dot_validate__pb2
from strmprivacy.api.entities.v1alpha import entities_v1alpha_pb2 as strmprivacy_dot_api_dot_entities_dot_v1alpha_dot_entities__v1alpha__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;strmprivacy/api/categories/v1alpha/categories_v1alpha.proto\x12\"strmprivacy.api.categories.v1alpha\x1a\x33strmprivacy/api/paging/v1alpha/paging_v1alpha.proto\x1a\x17validate/validate.proto\x1a\x37strmprivacy/api/entities/v1alpha/entities_v1alpha.proto\"\xa3\x01\n\x15ListCategoriesRequest\x12\x43\n\x04type\x18\x01 \x01(\x0e\x32/.strmprivacy.api.entities.v1alpha.Category.TypeR\x04type\x12\x45\n\tpage_info\x18\x02 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\"\xab\x01\n\x16ListCategoriesResponse\x12J\n\ncategories\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1alpha.CategoryR\ncategories\x12\x45\n\tpage_info\x18\x02 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\".\n\x12GetCategoryRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\"]\n\x13GetCategoryResponse\x12\x46\n\x08\x63\x61tegory\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1alpha.CategoryR\x08\x63\x61tegory\"_\n\x15UpsertCategoryRequest\x12\x46\n\x08\x63\x61tegory\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1alpha.CategoryR\x08\x63\x61tegory\"`\n\x16UpsertCategoryResponse\x12\x46\n\x08\x63\x61tegory\x18\x01 \x01(\x0b\x32*.strmprivacy.api.entities.v1alpha.CategoryR\x08\x63\x61tegory2\xa7\x03\n\x11\x43\x61tegoriesService\x12\x87\x01\n\x0eListCategories\x12\x39.strmprivacy.api.categories.v1alpha.ListCategoriesRequest\x1a:.strmprivacy.api.categories.v1alpha.ListCategoriesResponse\x12~\n\x0bGetCategory\x12\x36.strmprivacy.api.categories.v1alpha.GetCategoryRequest\x1a\x37.strmprivacy.api.categories.v1alpha.GetCategoryResponse\x12\x87\x01\n\x0eUpsertCategory\x12\x39.strmprivacy.api.categories.v1alpha.UpsertCategoryRequest\x1a:.strmprivacy.api.categories.v1alpha.UpsertCategoryResponseBy\n%io.strmprivacy.api.categories.v1alphaP\x01ZNgithub.com/strmprivacy/api-definitions-go/v3/api/categories/v1alpha;categoriesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.categories.v1alpha.categories_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%io.strmprivacy.api.categories.v1alphaP\001ZNgithub.com/strmprivacy/api-definitions-go/v3/api/categories/v1alpha;categories'
  _GETCATEGORYREQUEST.fields_by_name['id']._options = None
  _GETCATEGORYREQUEST.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTCATEGORIESREQUEST._serialized_start=235
  _LISTCATEGORIESREQUEST._serialized_end=398
  _LISTCATEGORIESRESPONSE._serialized_start=401
  _LISTCATEGORIESRESPONSE._serialized_end=572
  _GETCATEGORYREQUEST._serialized_start=574
  _GETCATEGORYREQUEST._serialized_end=620
  _GETCATEGORYRESPONSE._serialized_start=622
  _GETCATEGORYRESPONSE._serialized_end=715
  _UPSERTCATEGORYREQUEST._serialized_start=717
  _UPSERTCATEGORYREQUEST._serialized_end=812
  _UPSERTCATEGORYRESPONSE._serialized_start=814
  _UPSERTCATEGORYRESPONSE._serialized_end=910
  _CATEGORIESSERVICE._serialized_start=913
  _CATEGORIESSERVICE._serialized_end=1336
# @@protoc_insertion_point(module_scope)
