# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/notifications/v1/notifications_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/notifications/v1/notifications_v1.proto\x12 strmprivacy.api.notifications.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x1d\n\x1bReceiveNotificationsRequest\"v\n\x1cReceiveNotificationsResponse\x12V\n\x0cnotification\x18\x01 \x01(\x0b\x32\x32.strmprivacy.api.notifications.v1.UserNotificationR\x0cnotification\"\xca\x01\n\x18NotifySubscribersRequest\x12P\n\nentity_ref\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.GenericRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tentityRef\x12\\\n\x0cnotification\x18\x02 \x01(\x0b\x32..strmprivacy.api.notifications.v1.NotificationB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0cnotification\"\x1b\n\x19NotifySubscribersResponse\"\xad\x01\n\x12NotifyUsersRequest\x12\x39\n\x11\x65xternal_user_ids\x18\x01 \x03(\tB\r\xfa\x42\n\x92\x01\x07\"\x05r\x03\xb0\x01\x01R\x0f\x65xternalUserIds\x12\\\n\x0cnotification\x18\x02 \x01(\x0b\x32..strmprivacy.api.notifications.v1.NotificationB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0cnotification\"\x15\n\x13NotifyUsersResponse\"\x83\x02\n\x0cNotification\x12\x45\n\x0b\x63reate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xfa\x42\x05\xb2\x01\x02\x08\x00R\ncreateTime\x12@\n\x07\x63omment\x18\x02 \x01(\x0b\x32$.strmprivacy.api.entities.v1.CommentH\x00R\x07\x63omment\x12Z\n\x11\x61udit_trail_entry\x18\x03 \x01(\x0b\x32,.strmprivacy.api.entities.v1.AuditTrailEntryH\x00R\x0f\x61uditTrailEntryB\x0e\n\x0cnotification\"\xc8\x02\n\x10UserNotification\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x02id\x12\\\n\x0cnotification\x18\x02 \x01(\x0b\x32..strmprivacy.api.notifications.v1.NotificationB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0cnotification\x12\x1f\n\x06reason\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06reason\x12(\n\x10\x65xternal_user_id\x18\x04 \x01(\tR\x0e\x65xternalUserId\x12J\n\x0email_sent_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xfa\x42\x05\xb2\x01\x02\x08\x00R\x0cmailSentTime\x12\"\n\rhas_been_seen\x18\x06 \x01(\x08R\x0bhasBeenSeen\"\xa8\x01\n\x1dSubscribeNotificationsRequest\x12\x35\n\x10\x65xternal_user_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0e\x65xternalUserId\x12P\n\nentity_ref\x18\x02 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.GenericRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tentityRef\" \n\x1eSubscribeNotificationsResponse\"\xaa\x01\n\x1fUnSubscribeNotificationsRequest\x12\x35\n\x10\x65xternal_user_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0e\x65xternalUserId\x12P\n\nentity_ref\x18\x02 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.GenericRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tentityRef\"\"\n UnSubscribeNotificationsResponse\"Q\n\x18ListSubscriptionsRequest\x12\x35\n\x10\x65xternal_user_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0e\x65xternalUserId\"q\n\x19ListSubscriptionsResponse\x12T\n\rsubscriptions\x18\x01 \x03(\x0b\x32..strmprivacy.api.notifications.v1.SubscriptionR\rsubscriptions\"\x97\x01\n\x0cSubscription\x12\x35\n\x10\x65xternal_user_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0e\x65xternalUserId\x12P\n\nentity_ref\x18\x02 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.GenericRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tentityRef\"\xd8\x02\n\x18ListNotificationsRequest\x12\x35\n\x10\x65xternal_user_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0e\x65xternalUserId\x12P\n\nentity_ref\x18\x02 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.GenericRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x00R\tentityRef\x12\x1b\n\tpage_size\x18\x03 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x04 \x01(\tR\tpageToken\x12\x45\n\x0boffset_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xfa\x42\x05\xb2\x01\x02\x08\x00R\noffsetTime\x12\x30\n\x14include_already_seen\x18\x06 \x01(\x08R\x12includeAlreadySeen\"\x9d\x01\n\x19ListNotificationsResponse\x12X\n\rnotifications\x18\x01 \x03(\x0b\x32\x32.strmprivacy.api.notifications.v1.UserNotificationR\rnotifications\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\\\n$AlterNotificationsHasBeenSeenRequest\x12\x10\n\x03ids\x18\x01 \x03(\tR\x03ids\x12\"\n\rhas_been_seen\x18\x02 \x01(\x08R\x0bhasBeenSeen\"\'\n%AlterNotificationsHasBeenSeenResponse2\xce\t\n\x14NotificationsService\x12\x9b\x01\n\x16SubscribeNotifications\x12?.strmprivacy.api.notifications.v1.SubscribeNotificationsRequest\x1a@.strmprivacy.api.notifications.v1.SubscribeNotificationsResponse\x12\xa1\x01\n\x18UnSubscribeNotifications\x12\x41.strmprivacy.api.notifications.v1.UnSubscribeNotificationsRequest\x1a\x42.strmprivacy.api.notifications.v1.UnSubscribeNotificationsResponse\x12\x8c\x01\n\x11ListSubscriptions\x12:.strmprivacy.api.notifications.v1.ListSubscriptionsRequest\x1a;.strmprivacy.api.notifications.v1.ListSubscriptionsResponse\x12\x8c\x01\n\x11NotifySubscribers\x12:.strmprivacy.api.notifications.v1.NotifySubscribersRequest\x1a;.strmprivacy.api.notifications.v1.NotifySubscribersResponse\x12z\n\x0bNotifyUsers\x12\x34.strmprivacy.api.notifications.v1.NotifyUsersRequest\x1a\x35.strmprivacy.api.notifications.v1.NotifyUsersResponse\x12\x97\x01\n\x14ReceiveNotifications\x12=.strmprivacy.api.notifications.v1.ReceiveNotificationsRequest\x1a>.strmprivacy.api.notifications.v1.ReceiveNotificationsResponse0\x01\x12\x8c\x01\n\x11ListNotifications\x12:.strmprivacy.api.notifications.v1.ListNotificationsRequest\x1a;.strmprivacy.api.notifications.v1.ListNotificationsResponse\x12\xb0\x01\n\x1d\x41lterNotificationsHasBeenSeen\x12\x46.strmprivacy.api.notifications.v1.AlterNotificationsHasBeenSeenRequest\x1aG.strmprivacy.api.notifications.v1.AlterNotificationsHasBeenSeenResponseBx\n#io.strmprivacy.api.notifications.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v3/api/notifications/v1;notificationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.notifications.v1.notifications_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.notifications.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v3/api/notifications/v1;notifications'
  _NOTIFYSUBSCRIBERSREQUEST.fields_by_name['entity_ref']._options = None
  _NOTIFYSUBSCRIBERSREQUEST.fields_by_name['entity_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _NOTIFYSUBSCRIBERSREQUEST.fields_by_name['notification']._options = None
  _NOTIFYSUBSCRIBERSREQUEST.fields_by_name['notification']._serialized_options = b'\372B\005\212\001\002\020\001'
  _NOTIFYUSERSREQUEST.fields_by_name['external_user_ids']._options = None
  _NOTIFYUSERSREQUEST.fields_by_name['external_user_ids']._serialized_options = b'\372B\n\222\001\007\"\005r\003\260\001\001'
  _NOTIFYUSERSREQUEST.fields_by_name['notification']._options = None
  _NOTIFYUSERSREQUEST.fields_by_name['notification']._serialized_options = b'\372B\005\212\001\002\020\001'
  _NOTIFICATION.fields_by_name['create_time']._options = None
  _NOTIFICATION.fields_by_name['create_time']._serialized_options = b'\372B\005\262\001\002\010\000'
  _USERNOTIFICATION.fields_by_name['id']._options = None
  _USERNOTIFICATION.fields_by_name['id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _USERNOTIFICATION.fields_by_name['notification']._options = None
  _USERNOTIFICATION.fields_by_name['notification']._serialized_options = b'\372B\005\212\001\002\020\001'
  _USERNOTIFICATION.fields_by_name['reason']._options = None
  _USERNOTIFICATION.fields_by_name['reason']._serialized_options = b'\372B\004r\002\020\001'
  _USERNOTIFICATION.fields_by_name['mail_sent_time']._options = None
  _USERNOTIFICATION.fields_by_name['mail_sent_time']._serialized_options = b'\372B\005\262\001\002\010\000'
  _SUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['external_user_id']._options = None
  _SUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['external_user_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _SUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['entity_ref']._options = None
  _SUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['entity_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UNSUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['external_user_id']._options = None
  _UNSUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['external_user_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _UNSUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['entity_ref']._options = None
  _UNSUBSCRIBENOTIFICATIONSREQUEST.fields_by_name['entity_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTSUBSCRIPTIONSREQUEST.fields_by_name['external_user_id']._options = None
  _LISTSUBSCRIPTIONSREQUEST.fields_by_name['external_user_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _SUBSCRIPTION.fields_by_name['external_user_id']._options = None
  _SUBSCRIPTION.fields_by_name['external_user_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _SUBSCRIPTION.fields_by_name['entity_ref']._options = None
  _SUBSCRIPTION.fields_by_name['entity_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTNOTIFICATIONSREQUEST.fields_by_name['external_user_id']._options = None
  _LISTNOTIFICATIONSREQUEST.fields_by_name['external_user_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _LISTNOTIFICATIONSREQUEST.fields_by_name['entity_ref']._options = None
  _LISTNOTIFICATIONSREQUEST.fields_by_name['entity_ref']._serialized_options = b'\372B\005\212\001\002\020\000'
  _LISTNOTIFICATIONSREQUEST.fields_by_name['offset_time']._options = None
  _LISTNOTIFICATIONSREQUEST.fields_by_name['offset_time']._serialized_options = b'\372B\005\262\001\002\010\000'
  _RECEIVENOTIFICATIONSREQUEST._serialized_start=198
  _RECEIVENOTIFICATIONSREQUEST._serialized_end=227
  _RECEIVENOTIFICATIONSRESPONSE._serialized_start=229
  _RECEIVENOTIFICATIONSRESPONSE._serialized_end=347
  _NOTIFYSUBSCRIBERSREQUEST._serialized_start=350
  _NOTIFYSUBSCRIBERSREQUEST._serialized_end=552
  _NOTIFYSUBSCRIBERSRESPONSE._serialized_start=554
  _NOTIFYSUBSCRIBERSRESPONSE._serialized_end=581
  _NOTIFYUSERSREQUEST._serialized_start=584
  _NOTIFYUSERSREQUEST._serialized_end=757
  _NOTIFYUSERSRESPONSE._serialized_start=759
  _NOTIFYUSERSRESPONSE._serialized_end=780
  _NOTIFICATION._serialized_start=783
  _NOTIFICATION._serialized_end=1042
  _USERNOTIFICATION._serialized_start=1045
  _USERNOTIFICATION._serialized_end=1373
  _SUBSCRIBENOTIFICATIONSREQUEST._serialized_start=1376
  _SUBSCRIBENOTIFICATIONSREQUEST._serialized_end=1544
  _SUBSCRIBENOTIFICATIONSRESPONSE._serialized_start=1546
  _SUBSCRIBENOTIFICATIONSRESPONSE._serialized_end=1578
  _UNSUBSCRIBENOTIFICATIONSREQUEST._serialized_start=1581
  _UNSUBSCRIBENOTIFICATIONSREQUEST._serialized_end=1751
  _UNSUBSCRIBENOTIFICATIONSRESPONSE._serialized_start=1753
  _UNSUBSCRIBENOTIFICATIONSRESPONSE._serialized_end=1787
  _LISTSUBSCRIPTIONSREQUEST._serialized_start=1789
  _LISTSUBSCRIPTIONSREQUEST._serialized_end=1870
  _LISTSUBSCRIPTIONSRESPONSE._serialized_start=1872
  _LISTSUBSCRIPTIONSRESPONSE._serialized_end=1985
  _SUBSCRIPTION._serialized_start=1988
  _SUBSCRIPTION._serialized_end=2139
  _LISTNOTIFICATIONSREQUEST._serialized_start=2142
  _LISTNOTIFICATIONSREQUEST._serialized_end=2486
  _LISTNOTIFICATIONSRESPONSE._serialized_start=2489
  _LISTNOTIFICATIONSRESPONSE._serialized_end=2646
  _ALTERNOTIFICATIONSHASBEENSEENREQUEST._serialized_start=2648
  _ALTERNOTIFICATIONSHASBEENSEENREQUEST._serialized_end=2740
  _ALTERNOTIFICATIONSHASBEENSEENRESPONSE._serialized_start=2742
  _ALTERNOTIFICATIONSHASBEENSEENRESPONSE._serialized_end=2781
  _NOTIFICATIONSSERVICE._serialized_start=2784
  _NOTIFICATIONSSERVICE._serialized_end=4014
# @@protoc_insertion_point(module_scope)
