# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/audit/v1/audit_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'strmprivacy/api/audit/v1/audit_v1.proto\x12\x18strmprivacy.api.audit.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\xc6\x01\n\x14GetAuditTrailRequest\x12\x46\n\nentity_ref\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.GenericRefR\tentityRef\x12\x1b\n\tpage_size\x18\x02 \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12*\n\nproject_id\x18\x04 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\tprojectId\"\x87\x01\n\x15GetAuditTrailResponse\x12\x46\n\x07\x65ntries\x18\x01 \x03(\x0b\x32,.strmprivacy.api.entities.v1.AuditTrailEntryR\x07\x65ntries\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\x82\x01\n\x1c\x43reateAuditTrailEntryRequest\x12\x62\n\x11\x61udit_trail_entry\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1.AuditTrailEntryB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0f\x61uditTrailEntry\"y\n\x1d\x43reateAuditTrailEntryResponse\x12X\n\x11\x61udit_trail_entry\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1.AuditTrailEntryR\x0f\x61uditTrailEntry2\x8b\x02\n\x0c\x41uditService\x12p\n\rGetAuditTrail\x12..strmprivacy.api.audit.v1.GetAuditTrailRequest\x1a/.strmprivacy.api.audit.v1.GetAuditTrailResponse\x12\x88\x01\n\x15\x43reateAuditTrailEntry\x12\x36.strmprivacy.api.audit.v1.CreateAuditTrailEntryRequest\x1a\x37.strmprivacy.api.audit.v1.CreateAuditTrailEntryResponseB`\n\x1bio.strmprivacy.api.audit.v1P\x01Z?github.com/strmprivacy/api-definitions-go/v3/api/audit/v1;auditb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.audit.v1.audit_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033io.strmprivacy.api.audit.v1P\001Z?github.com/strmprivacy/api-definitions-go/v3/api/audit/v1;audit'
  _GETAUDITTRAILREQUEST.fields_by_name['project_id']._options = None
  _GETAUDITTRAILREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _CREATEAUDITTRAILENTRYREQUEST.fields_by_name['audit_trail_entry']._options = None
  _CREATEAUDITTRAILENTRYREQUEST.fields_by_name['audit_trail_entry']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETAUDITTRAILREQUEST._serialized_start=142
  _GETAUDITTRAILREQUEST._serialized_end=340
  _GETAUDITTRAILRESPONSE._serialized_start=343
  _GETAUDITTRAILRESPONSE._serialized_end=478
  _CREATEAUDITTRAILENTRYREQUEST._serialized_start=481
  _CREATEAUDITTRAILENTRYREQUEST._serialized_end=611
  _CREATEAUDITTRAILENTRYRESPONSE._serialized_start=613
  _CREATEAUDITTRAILENTRYRESPONSE._serialized_end=734
  _AUDITSERVICE._serialized_start=737
  _AUDITSERVICE._serialized_end=1004
# @@protoc_insertion_point(module_scope)
