# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/paging/v1/paging_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)strmprivacy/api/paging/v1/paging_v1.proto\x12\x19strmprivacy.api.paging.v1\"2\n\x12TimestampPageToken\x12\x1c\n\ttimestamp\x18\x01 \x01(\tR\ttimestamp\")\n\x0fOffsetPageToken\x12\x16\n\x06offset\x18\x01 \x01(\x03R\x06offset\"\xa5\x03\n\x15\x46ieldsOffsetPageToken\x12T\n\x06\x66ields\x18\x01 \x03(\x0b\x32<.strmprivacy.api.paging.v1.FieldsOffsetPageToken.FieldsEntryR\x06\x66ields\x1aw\n\x0b\x46ieldsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12R\n\x05value\x18\x02 \x01(\x0b\x32<.strmprivacy.api.paging.v1.FieldsOffsetPageToken.FieldOffsetR\x05value:\x02\x38\x01\x1a\x83\x01\n\x0b\x46ieldOffset\x12\x1d\n\nlast_value\x18\x01 \x01(\tR\tlastValue\x12U\n\x08ordering\x18\x02 \x01(\x0e\x32\x39.strmprivacy.api.paging.v1.FieldsOffsetPageToken.OrderingR\x08ordering\"7\n\x08Ordering\x12\x18\n\x14ORDERING_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41SC\x10\x01\x12\x08\n\x04\x44\x45SC\x10\x02\x42\x63\n\x1cio.strmprivacy.api.paging.v1P\x01ZAgithub.com/strmprivacy/api-definitions-go/v3/api/paging/v1;pagingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.paging.v1.paging_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034io.strmprivacy.api.paging.v1P\001ZAgithub.com/strmprivacy/api-definitions-go/v3/api/paging/v1;paging'
  _FIELDSOFFSETPAGETOKEN_FIELDSENTRY._options = None
  _FIELDSOFFSETPAGETOKEN_FIELDSENTRY._serialized_options = b'8\001'
  _TIMESTAMPPAGETOKEN._serialized_start=72
  _TIMESTAMPPAGETOKEN._serialized_end=122
  _OFFSETPAGETOKEN._serialized_start=124
  _OFFSETPAGETOKEN._serialized_end=165
  _FIELDSOFFSETPAGETOKEN._serialized_start=168
  _FIELDSOFFSETPAGETOKEN._serialized_end=589
  _FIELDSOFFSETPAGETOKEN_FIELDSENTRY._serialized_start=279
  _FIELDSOFFSETPAGETOKEN_FIELDSENTRY._serialized_end=398
  _FIELDSOFFSETPAGETOKEN_FIELDOFFSET._serialized_start=401
  _FIELDSOFFSETPAGETOKEN_FIELDOFFSET._serialized_end=532
  _FIELDSOFFSETPAGETOKEN_ORDERING._serialized_start=534
  _FIELDSOFFSETPAGETOKEN_ORDERING._serialized_end=589
# @@protoc_insertion_point(module_scope)
