# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/project_plans/v1alpha/project_plans_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1alpha import entities_v1alpha_pb2 as strmprivacy_dot_api_dot_entities_dot_v1alpha_dot_entities__v1alpha__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAstrmprivacy/api/project_plans/v1alpha/project_plans_v1alpha.proto\x12%strmprivacy.api.project_plans.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a\x37strmprivacy/api/entities/v1alpha/entities_v1alpha.proto\x1a\x17validate/validate.proto\"x\n\x17ListProjectPlansRequest\x12#\n\x0bis_template\x18\x01 \x01(\x08\x42\x02\x18\x01R\nisTemplate\x12\x38\n\x16include_dummy_template\x18\x02 \x01(\x08\x42\x02\x18\x01R\x14includeDummyTemplate\"n\n\x18ListProjectPlansResponse\x12R\n\rproject_plans\x18\x01 \x03(\x0b\x32-.strmprivacy.api.entities.v1alpha.ProjectPlanR\x0cprojectPlans\"@\n\x15GetProjectPlanRequest\x12\'\n\nproject_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"o\n\x16GetProjectPlanResponse\x12U\n\x0cproject_plan\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.ProjectPlanB\x03\xe0\x41\x02R\x0bprojectPlan\"q\n\x18UpsertProjectPlanRequest\x12U\n\x0cproject_plan\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.ProjectPlanB\x03\xe0\x41\x02R\x0bprojectPlan\"r\n\x19UpsertProjectPlanResponse\x12U\n\x0cproject_plan\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.ProjectPlanB\x03\xe0\x41\x02R\x0bprojectPlan\">\n\x18\x44\x65leteProjectPlanRequest\x12\"\n\nproject_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x1b\n\x19\x44\x65leteProjectPlanResponse\"\xd6\x01\n\x17\x42uildProjectPlanRequest\x12\x41\n\x18project_plan_template_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x15projectPlanTemplateId\x12*\n\nproject_id\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\tprojectId\x12#\n\rvalidate_only\x18\x03 \x01(\x08R\x0cvalidateOnly\x12\'\n\x0f\x61llow_overwrite\x18\x04 \x01(\x08R\x0e\x61llowOverwrite\"l\n\x18\x42uildProjectPlanResponse\x12P\n\x0cproject_plan\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.ProjectPlanR\x0bprojectPlan\"\xda\x01\n&BuildProjectPlanFromTemplateIdsRequest\x12\x39\n\x11\x66orm_template_ids\x18\x01 \x03(\tB\r\xfa\x42\n\x92\x01\x07\"\x05r\x03\xb0\x01\x01R\x0f\x66ormTemplateIds\x12\'\n\nproject_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\x12#\n\rvalidate_only\x18\x03 \x01(\x08R\x0cvalidateOnly\x12\'\n\x0f\x61llow_overwrite\x18\x04 \x01(\x08R\x0e\x61llowOverwrite\"{\n\'BuildProjectPlanFromTemplateIdsResponse\x12P\n\x0cproject_plan\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.ProjectPlanR\x0bprojectPlan2\xc6\x07\n\x13ProjectPlansService\x12\x93\x01\n\x10ListProjectPlans\x12>.strmprivacy.api.project_plans.v1alpha.ListProjectPlansRequest\x1a?.strmprivacy.api.project_plans.v1alpha.ListProjectPlansResponse\x12\x8d\x01\n\x0eGetProjectPlan\x12<.strmprivacy.api.project_plans.v1alpha.GetProjectPlanRequest\x1a=.strmprivacy.api.project_plans.v1alpha.GetProjectPlanResponse\x12\x96\x01\n\x11UpsertProjectPlan\x12?.strmprivacy.api.project_plans.v1alpha.UpsertProjectPlanRequest\x1a@.strmprivacy.api.project_plans.v1alpha.UpsertProjectPlanResponse\x12\x96\x01\n\x11\x44\x65leteProjectPlan\x12?.strmprivacy.api.project_plans.v1alpha.DeleteProjectPlanRequest\x1a@.strmprivacy.api.project_plans.v1alpha.DeleteProjectPlanResponse\x12\x93\x01\n\x10\x42uildProjectPlan\x12>.strmprivacy.api.project_plans.v1alpha.BuildProjectPlanRequest\x1a?.strmprivacy.api.project_plans.v1alpha.BuildProjectPlanResponse\x12\xc0\x01\n\x1f\x42uildProjectPlanFromTemplateIds\x12M.strmprivacy.api.project_plans.v1alpha.BuildProjectPlanFromTemplateIdsRequest\x1aN.strmprivacy.api.project_plans.v1alpha.BuildProjectPlanFromTemplateIdsResponseB\x82\x01\n(io.strmprivacy.api.project_plans.v1alphaP\x01ZTgithub.com/strmprivacy/api-definitions-go/v3/api/project_plans/v1alpha;project_plansb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.project_plans.v1alpha.project_plans_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.strmprivacy.api.project_plans.v1alphaP\001ZTgithub.com/strmprivacy/api-definitions-go/v3/api/project_plans/v1alpha;project_plans'
  _LISTPROJECTPLANSREQUEST.fields_by_name['is_template']._options = None
  _LISTPROJECTPLANSREQUEST.fields_by_name['is_template']._serialized_options = b'\030\001'
  _LISTPROJECTPLANSREQUEST.fields_by_name['include_dummy_template']._options = None
  _LISTPROJECTPLANSREQUEST.fields_by_name['include_dummy_template']._serialized_options = b'\030\001'
  _GETPROJECTPLANREQUEST.fields_by_name['project_id']._options = None
  _GETPROJECTPLANREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETPROJECTPLANRESPONSE.fields_by_name['project_plan']._options = None
  _GETPROJECTPLANRESPONSE.fields_by_name['project_plan']._serialized_options = b'\340A\002'
  _UPSERTPROJECTPLANREQUEST.fields_by_name['project_plan']._options = None
  _UPSERTPROJECTPLANREQUEST.fields_by_name['project_plan']._serialized_options = b'\340A\002'
  _UPSERTPROJECTPLANRESPONSE.fields_by_name['project_plan']._options = None
  _UPSERTPROJECTPLANRESPONSE.fields_by_name['project_plan']._serialized_options = b'\340A\002'
  _DELETEPROJECTPLANREQUEST.fields_by_name['project_id']._options = None
  _DELETEPROJECTPLANREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _BUILDPROJECTPLANREQUEST.fields_by_name['project_plan_template_id']._options = None
  _BUILDPROJECTPLANREQUEST.fields_by_name['project_plan_template_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _BUILDPROJECTPLANREQUEST.fields_by_name['project_id']._options = None
  _BUILDPROJECTPLANREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _BUILDPROJECTPLANFROMTEMPLATEIDSREQUEST.fields_by_name['form_template_ids']._options = None
  _BUILDPROJECTPLANFROMTEMPLATEIDSREQUEST.fields_by_name['form_template_ids']._serialized_options = b'\372B\n\222\001\007\"\005r\003\260\001\001'
  _BUILDPROJECTPLANFROMTEMPLATEIDSREQUEST.fields_by_name['project_id']._options = None
  _BUILDPROJECTPLANFROMTEMPLATEIDSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTPROJECTPLANSREQUEST._serialized_start=223
  _LISTPROJECTPLANSREQUEST._serialized_end=343
  _LISTPROJECTPLANSRESPONSE._serialized_start=345
  _LISTPROJECTPLANSRESPONSE._serialized_end=455
  _GETPROJECTPLANREQUEST._serialized_start=457
  _GETPROJECTPLANREQUEST._serialized_end=521
  _GETPROJECTPLANRESPONSE._serialized_start=523
  _GETPROJECTPLANRESPONSE._serialized_end=634
  _UPSERTPROJECTPLANREQUEST._serialized_start=636
  _UPSERTPROJECTPLANREQUEST._serialized_end=749
  _UPSERTPROJECTPLANRESPONSE._serialized_start=751
  _UPSERTPROJECTPLANRESPONSE._serialized_end=865
  _DELETEPROJECTPLANREQUEST._serialized_start=867
  _DELETEPROJECTPLANREQUEST._serialized_end=929
  _DELETEPROJECTPLANRESPONSE._serialized_start=931
  _DELETEPROJECTPLANRESPONSE._serialized_end=958
  _BUILDPROJECTPLANREQUEST._serialized_start=961
  _BUILDPROJECTPLANREQUEST._serialized_end=1175
  _BUILDPROJECTPLANRESPONSE._serialized_start=1177
  _BUILDPROJECTPLANRESPONSE._serialized_end=1285
  _BUILDPROJECTPLANFROMTEMPLATEIDSREQUEST._serialized_start=1288
  _BUILDPROJECTPLANFROMTEMPLATEIDSREQUEST._serialized_end=1506
  _BUILDPROJECTPLANFROMTEMPLATEIDSRESPONSE._serialized_start=1508
  _BUILDPROJECTPLANFROMTEMPLATEIDSRESPONSE._serialized_end=1631
  _PROJECTPLANSSERVICE._serialized_start=1634
  _PROJECTPLANSSERVICE._serialized_end=2600
# @@protoc_insertion_point(module_scope)
