# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/data_assets/v1alpha/data_assets_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1alpha import entities_v1alpha_pb2 as strmprivacy_dot_api_dot_entities_dot_v1alpha_dot_entities__v1alpha__pb2
from strmprivacy.api.paging.v1alpha import paging_v1alpha_pb2 as strmprivacy_dot_api_dot_paging_dot_v1alpha_dot_paging__v1alpha__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=strmprivacy/api/data_assets/v1alpha/data_assets_v1alpha.proto\x12#strmprivacy.api.data_assets.v1alpha\x1a\x37strmprivacy/api/entities/v1alpha/entities_v1alpha.proto\x1a\x33strmprivacy/api/paging/v1alpha/paging_v1alpha.proto\x1a\x17validate/validate.proto\"^\n\x15ListDataAssetsRequest\x12\x45\n\tpage_info\x18\x01 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\"\xad\x01\n\x16ListDataAssetsResponse\x12L\n\x0b\x64\x61ta_assets\x18\x01 \x03(\x0b\x32+.strmprivacy.api.entities.v1alpha.DataAssetR\ndataAssets\x12\x45\n\tpage_info\x18\x02 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\"/\n\x13GetDataAssetRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\"b\n\x14GetDataAssetResponse\x12J\n\ndata_asset\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1alpha.DataAssetR\tdataAsset\"d\n\x16UpsertDataAssetRequest\x12J\n\ndata_asset\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1alpha.DataAssetR\tdataAsset\"e\n\x17UpsertDataAssetResponse\x12J\n\ndata_asset\x18\x01 \x01(\x0b\x32+.strmprivacy.api.entities.v1alpha.DataAssetR\tdataAsset2\xb4\x03\n\x11\x44\x61taAssetsService\x12\x89\x01\n\x0eListDataAssets\x12:.strmprivacy.api.data_assets.v1alpha.ListDataAssetsRequest\x1a;.strmprivacy.api.data_assets.v1alpha.ListDataAssetsResponse\x12\x83\x01\n\x0cGetDataAsset\x12\x38.strmprivacy.api.data_assets.v1alpha.GetDataAssetRequest\x1a\x39.strmprivacy.api.data_assets.v1alpha.GetDataAssetResponse\x12\x8c\x01\n\x0fUpsertDataAsset\x12;.strmprivacy.api.data_assets.v1alpha.UpsertDataAssetRequest\x1a<.strmprivacy.api.data_assets.v1alpha.UpsertDataAssetResponseB|\n&io.strmprivacy.api.data_assets.v1alphaP\x01ZPgithub.com/strmprivacy/api-definitions-go/v3/api/data_assets/v1alpha;data_assetsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.data_assets.v1alpha.data_assets_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&io.strmprivacy.api.data_assets.v1alphaP\001ZPgithub.com/strmprivacy/api-definitions-go/v3/api/data_assets/v1alpha;data_assets'
  _GETDATAASSETREQUEST.fields_by_name['id']._options = None
  _GETDATAASSETREQUEST.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTDATAASSETSREQUEST._serialized_start=237
  _LISTDATAASSETSREQUEST._serialized_end=331
  _LISTDATAASSETSRESPONSE._serialized_start=334
  _LISTDATAASSETSRESPONSE._serialized_end=507
  _GETDATAASSETREQUEST._serialized_start=509
  _GETDATAASSETREQUEST._serialized_end=556
  _GETDATAASSETRESPONSE._serialized_start=558
  _GETDATAASSETRESPONSE._serialized_end=656
  _UPSERTDATAASSETREQUEST._serialized_start=658
  _UPSERTDATAASSETREQUEST._serialized_end=758
  _UPSERTDATAASSETRESPONSE._serialized_start=760
  _UPSERTDATAASSETRESPONSE._serialized_end=861
  _DATAASSETSSERVICE._serialized_start=864
  _DATAASSETSSERVICE._serialized_end=1300
# @@protoc_insertion_point(module_scope)
