# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.data_assets.v1alpha import data_assets_v1alpha_pb2 as strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2


class DataAssetsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataAssets = channel.unary_unary(
                '/strmprivacy.api.data_assets.v1alpha.DataAssetsService/ListDataAssets',
                request_serializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.ListDataAssetsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.ListDataAssetsResponse.FromString,
                )
        self.GetDataAsset = channel.unary_unary(
                '/strmprivacy.api.data_assets.v1alpha.DataAssetsService/GetDataAsset',
                request_serializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.GetDataAssetRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.GetDataAssetResponse.FromString,
                )
        self.UpsertDataAsset = channel.unary_unary(
                '/strmprivacy.api.data_assets.v1alpha.DataAssetsService/UpsertDataAsset',
                request_serializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.UpsertDataAssetRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.UpsertDataAssetResponse.FromString,
                )


class DataAssetsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDataAssets(self, request, context):
        """List all data assets for an organization. The organization is derived from the calling user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataAsset(self, request, context):
        """Get a data asset by its id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertDataAsset(self, request, context):
        """Create or update a data asset.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataAssetsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataAssets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataAssets,
                    request_deserializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.ListDataAssetsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.ListDataAssetsResponse.SerializeToString,
            ),
            'GetDataAsset': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataAsset,
                    request_deserializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.GetDataAssetRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.GetDataAssetResponse.SerializeToString,
            ),
            'UpsertDataAsset': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertDataAsset,
                    request_deserializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.UpsertDataAssetRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.UpsertDataAssetResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.data_assets.v1alpha.DataAssetsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataAssetsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDataAssets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_assets.v1alpha.DataAssetsService/ListDataAssets',
            strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.ListDataAssetsRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.ListDataAssetsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataAsset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_assets.v1alpha.DataAssetsService/GetDataAsset',
            strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.GetDataAssetRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.GetDataAssetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpsertDataAsset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.data_assets.v1alpha.DataAssetsService/UpsertDataAsset',
            strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.UpsertDataAssetRequest.SerializeToString,
            strmprivacy_dot_api_dot_data__assets_dot_v1alpha_dot_data__assets__v1alpha__pb2.UpsertDataAssetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
