# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/entities/v1alpha/entities_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from validate import validate_pb2 as validate_dot_validate__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/entities/v1alpha/entities_v1alpha.proto\x12 strmprivacy.api.entities.v1alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"y\n\x0bProjectPlan\x12\'\n\nproject_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\x12\x41\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\'.strmprivacy.api.entities.v1alpha.EntryR\x07\x65ntries\"\xba\x03\n\x0c\x46ormTemplate\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x31\n\x0forganization_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x0eorganizationId\x12Z\n\x05items\x18\x04 \x03(\x0b\x32\x44.strmprivacy.api.entities.v1alpha.FormTemplate.EntryOrFormTemplateIdR\x05items\x12*\n\x11is_project_intake\x18\x05 \x01(\x08R\x0fisProjectIntake\x1a\xc0\x01\n\x15\x45ntryOrFormTemplateId\x12^\n\rform_template\x18\x01 \x01(\x0b\x32\x37.strmprivacy.api.entities.v1alpha.FormTemplateReferenceH\x00R\x0c\x66ormTemplate\x12?\n\x05\x65ntry\x18\x02 \x01(\x0b\x32\'.strmprivacy.api.entities.v1alpha.EntryH\x00R\x05\x65ntryB\x06\n\x04part\"V\n\x15\x46ormTemplateReference\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\x12#\n\rrender_inline\x18\x02 \x01(\x08R\x0crenderInline\"\xbb\x19\n\x05\x45ntry\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x02id\x12\x1e\n\x04name\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x18\x64\xd0\x01\x01R\x04name\x12%\n\x07\x63ontent\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\x18\x88\'\xd0\x01\x01R\x07\x63ontent\x12?\n\rcreation_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x63reationTime\x12\x35\n\x08\x64ue_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x64ueTime\x12\x43\n\x0f\x63ompletion_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0e\x63ompletionTime\x12;\n\x07\x63reator\x18\x07 \x01(\x0b\x32!.strmprivacy.api.entities.v1.UserR\x07\x63reator\x12=\n\x08\x61ssignee\x18\x08 \x01(\x0b\x32!.strmprivacy.api.entities.v1.UserR\x08\x61ssignee\x12\x1b\n\thelp_text\x18\t \x01(\tR\x08helpText\x12\x16\n\x06remark\x18\n \x01(\tR\x06remark\x12$\n\x0e\x63\x61n_be_deleted\x18\x0b \x01(\x08R\x0c\x63\x61nBeDeleted\x12\x35\n\x10\x66orm_template_id\x18\x0c \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0e\x66ormTemplateId\x12\x42\n\x04task\x18\r \x01(\x0b\x32,.strmprivacy.api.entities.v1alpha.Entry.TaskH\x00R\x04task\x12[\n\rdata_contract\x18\x0e \x01(\x0b\x32\x34.strmprivacy.api.entities.v1alpha.Entry.DataContractH\x00R\x0c\x64\x61taContract\x12N\n\x08\x64ocument\x18\x0f \x01(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.Entry.DocumentH\x00R\x08\x64ocument\x12N\n\x08pipeline\x18\x10 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.Entry.PipelineH\x00R\x08pipeline\x12N\n\x08question\x18\x11 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.Entry.QuestionH\x00R\x08question\x12V\n\x07\x63hoices\x18\x12 \x01(\x0b\x32:.strmprivacy.api.entities.v1alpha.Entry.MultipleChoiceItemH\x00R\x07\x63hoices\x12\x14\n\x04html\x18\x13 \x01(\tH\x00R\x04html\x12X\n\x0csection_open\x18\x14 \x01(\x0b\x32\x33.strmprivacy.api.entities.v1alpha.Entry.SectionOpenH\x00R\x0bsectionOpen\x12[\n\rsection_close\x18\x15 \x01(\x0b\x32\x34.strmprivacy.api.entities.v1alpha.Entry.SectionCloseH\x00R\x0csectionClose\x12Y\n\radd_one_entry\x18m \x01(\x0b\x32\x33.strmprivacy.api.entities.v1alpha.Entry.AddOneEntryH\x00R\x0b\x61\x64\x64OneEntry\x1a\x99\x04\n\x0b\x41\x64\x64OneEntry\x12\x42\n\x04task\x18\x01 \x01(\x0b\x32,.strmprivacy.api.entities.v1alpha.Entry.TaskH\x00R\x04task\x12[\n\rdata_contract\x18\x02 \x01(\x0b\x32\x34.strmprivacy.api.entities.v1alpha.Entry.DataContractH\x00R\x0c\x64\x61taContract\x12N\n\x08\x64ocument\x18\x03 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.Entry.DocumentH\x00R\x08\x64ocument\x12N\n\x08pipeline\x18\x04 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.Entry.PipelineH\x00R\x08pipeline\x12N\n\x08question\x18\x05 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.Entry.QuestionH\x00R\x08question\x12V\n\x07\x63hoices\x18\x06 \x01(\x0b\x32:.strmprivacy.api.entities.v1alpha.Entry.MultipleChoiceItemH\x00R\x07\x63hoices\x12\x14\n\x04html\x18\x07 \x01(\tH\x00R\x04htmlB\x0b\n\x04type\x12\x03\xf8\x42\x01\x1a\x06\n\x04Task\x1aX\n\x0c\x44\x61taContract\x12H\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x1a\x38\n\x08\x44ocument\x12\x1a\n\x08\x66ilename\x18\x02 \x01(\tR\x08\x66ilename\x12\x10\n\x03uri\x18\x03 \x01(\tR\x03uri\x1a\xa1\x01\n\x08Pipeline\x12@\n\x06stream\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefH\x00R\x06stream\x12G\n\tbatch_job\x18\x03 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefH\x00R\x08\x62\x61tchJobB\n\n\x08pipeline\x1a\xb9\x01\n\x08Question\x12m\n\x12\x61nswers_and_labels\x18\x01 \x03(\x0b\x32?.strmprivacy.api.entities.v1alpha.Entry.Question.AnswerAndLabelR\x10\x61nswersAndLabels\x1a>\n\x0e\x41nswerAndLabel\x12\x16\n\x06\x61nswer\x18\x01 \x01(\tR\x06\x61nswer\x12\x14\n\x05label\x18\x02 \x01(\tR\x05label\x1a\xe3\x02\n\x12MultipleChoiceItem\x12\x12\n\x04text\x18\x01 \x01(\tR\x04text\x12\x18\n\x07\x63hoices\x18\x02 \x03(\tR\x07\x63hoices\x12\x18\n\x07weights\x18\x03 \x03(\x02R\x07weights\x12\x18\n\x07\x61nswers\x18\x04 \x03(\x05R\x07\x61nswers\x12V\n\x05style\x18\x05 \x01(\x0e\x32@.strmprivacy.api.entities.v1alpha.Entry.MultipleChoiceItem.StyleR\x05style\x12L\n\x1b\x61ssociated_form_template_id\x18\x06 \x03(\tB\r\xfa\x42\n\x92\x01\x07\"\x05r\x03\xb0\x01\x01R\x18\x61ssociatedFormTemplateId\"E\n\x05Style\x12\x15\n\x11STYLE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43HECKBOX\x10\x01\x12\x0c\n\x08\x44ROPDOWN\x10\x02\x12\t\n\x05RADIO\x10\x03\x1a\x99\x01\n\x12RiskAssessmentItem\x12\x12\n\x04risk\x18\x02 \x01(\tR\x04risk\x12\'\n\x0fharm_likelihood\x18\x03 \x01(\tR\x0eharmLikelihood\x12#\n\rharm_severity\x18\x04 \x01(\tR\x0charmSeverity\x12!\n\x0coverall_risk\x18\x05 \x01(\tR\x0boverallRisk\x1a\xbb\x01\n\x12RiskMitigationItem\x12\x12\n\x04risk\x18\x02 \x01(\tR\x04risk\x12!\n\x0coverall_risk\x18\x03 \x01(\tR\x0boverallRisk\x12-\n\x12mitigation_measure\x18\x05 \x01(\tR\x11mitigationMeasure\x12#\n\rresidual_risk\x18\x06 \x01(\tR\x0cresidualRisk\x12\x1a\n\x08\x61pproval\x18\x07 \x01(\tR\x08\x61pproval\x1aI\n\rRecordingItem\x12\x1e\n\nparticular\x18\x02 \x01(\tR\nparticular\x12\x18\n\x07remarks\x18\x04 \x01(\tR\x07remarks\x1a\x32\n\x0bSectionOpen\x12#\n\rrender_inline\x18\x01 \x01(\x08R\x0crenderInline\x1a\x0e\n\x0cSectionCloseB\x0b\n\x04item\x12\x03\xf8\x42\x01\"\xd1\x02\n\x0e\x43ontactDetails\x12P\n\x04type\x18\x01 \x01(\x0e\x32<.strmprivacy.api.entities.v1alpha.ContactDetails.ContactTypeR\x04type\x12\x1d\n\nother_type\x18\x02 \x01(\tR\totherType\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x18\n\x07\x61\x64\x64ress\x18\x04 \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05\x65mail\x18\x05 \x01(\tR\x05\x65mail\x12\x14\n\x05phone\x18\x06 \x01(\tR\x05phone\"t\n\x0b\x43ontactType\x12\x1c\n\x18\x43ONTACT_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PRIMARY\x10\x01\x12\x12\n\x0eREPRESENTATIVE\x10\x02\x12\x1b\n\x17\x44\x41TA_PROTECTION_OFFICER\x10\x03\x12\t\n\x05OTHER\x10\x04\"\xc2\x03\n\x05Party\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x02id\x12\x1a\n\x08\x65xternal\x18\x02 \x01(\x08R\x08\x65xternal\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12,\n\x0bregion_code\x18\x04 \x01(\tB\x0b\xfa\x42\x08r\x06\x98\x01\x02\xd0\x01\x01R\nregionCode\x12Y\n\x0f\x63ontact_details\x18\x05 \x03(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.ContactDetailsR\x0e\x63ontactDetails\x12;\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nupdateTime\x1aI\n\x04List\x12\x41\n\x07parties\x18\x01 \x03(\x0b\x32\'.strmprivacy.api.entities.v1alpha.PartyR\x07parties\"[\n\x0cRelationType\x12\x1d\n\x19RELATION_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nCONTROLLER\x10\x01\x12\r\n\tPROCESSOR\x10\x02\x12\r\n\tRECIPIENT\x10\x03\"\xa9\x03\n\x08\x43\x61tegory\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x43\n\x04type\x18\x03 \x01(\x0e\x32/.strmprivacy.api.entities.v1alpha.Category.TypeR\x04type\x12;\n\x0bupdate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nupdateTime\x1aR\n\x04List\x12J\n\ncategories\x18\x01 \x03(\x0b\x32*.strmprivacy.api.entities.v1alpha.CategoryR\ncategories\"\x95\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x44\x41TA\x10\x01\x12\x10\n\x0c\x44\x41TA_SUBJECT\x10\x02\x12\x12\n\x0e\x44\x41TA_RECIPIENT\x10\x03\x12\x0e\n\nDATA_ASSET\x10\x04\x12\x11\n\rPERSONAL_DATA\x10\x05\x12\x0e\n\nPROCESSING\x10\x06\x12\x14\n\x10SECURITY_MEASURE\x10\x07\"\x87\x04\n\tDataAsset\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12J\n\ncategories\x18\x03 \x03(\x0b\x32*.strmprivacy.api.entities.v1alpha.CategoryR\ncategories\x12L\n\rhosting_party\x18\x04 \x01(\x0b\x32\'.strmprivacy.api.entities.v1alpha.PartyR\x0chostingParty\x12.\n\x13\x63ontact_person_name\x18\x05 \x01(\tR\x11\x63ontactPersonName\x12,\n\x0bregion_code\x18\x06 \x01(\tB\x0b\xfa\x42\x08r\x06\x98\x01\x02\xd0\x01\x01R\nregionCode\x12;\n\x0bupdate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nupdateTime\x1aT\n\x04List\x12L\n\x0b\x64\x61ta_assets\x18\x01 \x03(\x0b\x32+.strmprivacy.api.entities.v1alpha.DataAssetR\ndataAssets\">\n\x0cRelationType\x12\x1d\n\x19RELATION_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x44\x41TA_SOURCE\x10\x01\"\xdd\t\n\x04Ropa\x12\x34\n\x0forganization_id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0eorganizationId\x12G\n\x07records\x18\x02 \x03(\x0b\x32-.strmprivacy.api.entities.v1alpha.Ropa.RecordR\x07records\x1a\xd5\x08\n\x06Record\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x02id\x12\x34\n\x0forganization_id\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0eorganizationId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12;\n\x0bupdate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nupdateTime\x12\x42\n\x0bupdate_user\x18\x05 \x01(\x0b\x32!.strmprivacy.api.entities.v1.UserR\nupdateUser\x12\x18\n\x07version\x18\x06 \x01(\x05R\x07version\x12T\n\x07parties\x18\x07 \x03(\x0b\x32:.strmprivacy.api.entities.v1alpha.Ropa.Record.PartiesEntryR\x07parties\x12%\n\x0epurpose_levels\x18\x08 \x03(\x05R\rpurposeLevels\x12]\n\ncategories\x18\t \x03(\x0b\x32=.strmprivacy.api.entities.v1alpha.Ropa.Record.CategoriesEntryR\ncategories\x12*\n\x11\x64\x61ta_contract_ids\x18\n \x03(\tR\x0f\x64\x61taContractIds\x12^\n\x0b\x64\x61ta_assets\x18\x0b \x03(\x0b\x32=.strmprivacy.api.entities.v1alpha.Ropa.Record.DataAssetsEntryR\ndataAssets\x12\x32\n\x15\x64\x61ta_transfer_details\x18\x0c \x01(\tR\x13\x64\x61taTransferDetails\x12\x39\n\x19\x64\x61ta_retention_policy_ids\x18\r \x03(\tR\x16\x64\x61taRetentionPolicyIds\x12\'\n\x0f\x61\x64\x64itional_info\x18\x0e \x01(\tR\x0e\x61\x64\x64itionalInfo\x1ah\n\x0cPartiesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1alpha.Party.ListR\x05value:\x02\x38\x01\x1an\n\x0f\x43\x61tegoriesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x45\n\x05value\x18\x02 \x01(\x0b\x32/.strmprivacy.api.entities.v1alpha.Category.ListR\x05value:\x02\x38\x01\x1ao\n\x0f\x44\x61taAssetsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x30.strmprivacy.api.entities.v1alpha.DataAsset.ListR\x05value:\x02\x38\x01\x42s\n#io.strmprivacy.api.entities.v1alphaP\x01ZJgithub.com/strmprivacy/api-definitions-go/v3/api/entities/v1alpha;entitiesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.entities.v1alpha.entities_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.entities.v1alphaP\001ZJgithub.com/strmprivacy/api-definitions-go/v3/api/entities/v1alpha;entities'
  _PROJECTPLAN.fields_by_name['project_id']._options = None
  _PROJECTPLAN.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _FORMTEMPLATE.fields_by_name['id']._options = None
  _FORMTEMPLATE.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _FORMTEMPLATE.fields_by_name['organization_id']._options = None
  _FORMTEMPLATE.fields_by_name['organization_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _FORMTEMPLATEREFERENCE.fields_by_name['id']._options = None
  _FORMTEMPLATEREFERENCE.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _ENTRY_ADDONEENTRY.oneofs_by_name['type']._options = None
  _ENTRY_ADDONEENTRY.oneofs_by_name['type']._serialized_options = b'\370B\001'
  _ENTRY_DATACONTRACT.fields_by_name['ref']._options = None
  _ENTRY_DATACONTRACT.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ENTRY_MULTIPLECHOICEITEM.fields_by_name['associated_form_template_id']._options = None
  _ENTRY_MULTIPLECHOICEITEM.fields_by_name['associated_form_template_id']._serialized_options = b'\372B\n\222\001\007\"\005r\003\260\001\001'
  _ENTRY.oneofs_by_name['item']._options = None
  _ENTRY.oneofs_by_name['item']._serialized_options = b'\370B\001'
  _ENTRY.fields_by_name['id']._options = None
  _ENTRY.fields_by_name['id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _ENTRY.fields_by_name['name']._options = None
  _ENTRY.fields_by_name['name']._serialized_options = b'\372B\007r\005\030d\320\001\001'
  _ENTRY.fields_by_name['content']._options = None
  _ENTRY.fields_by_name['content']._serialized_options = b'\372B\010r\006\030\210\'\320\001\001'
  _ENTRY.fields_by_name['form_template_id']._options = None
  _ENTRY.fields_by_name['form_template_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _PARTY.fields_by_name['id']._options = None
  _PARTY.fields_by_name['id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _PARTY.fields_by_name['region_code']._options = None
  _PARTY.fields_by_name['region_code']._serialized_options = b'\372B\010r\006\230\001\002\320\001\001'
  _CATEGORY.fields_by_name['id']._options = None
  _CATEGORY.fields_by_name['id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _DATAASSET.fields_by_name['id']._options = None
  _DATAASSET.fields_by_name['id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _DATAASSET.fields_by_name['region_code']._options = None
  _DATAASSET.fields_by_name['region_code']._serialized_options = b'\372B\010r\006\230\001\002\320\001\001'
  _ROPA_RECORD_PARTIESENTRY._options = None
  _ROPA_RECORD_PARTIESENTRY._serialized_options = b'8\001'
  _ROPA_RECORD_CATEGORIESENTRY._options = None
  _ROPA_RECORD_CATEGORIESENTRY._serialized_options = b'8\001'
  _ROPA_RECORD_DATAASSETSENTRY._options = None
  _ROPA_RECORD_DATAASSETSENTRY._serialized_options = b'8\001'
  _ROPA_RECORD.fields_by_name['id']._options = None
  _ROPA_RECORD.fields_by_name['id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _ROPA_RECORD.fields_by_name['organization_id']._options = None
  _ROPA_RECORD.fields_by_name['organization_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _ROPA.fields_by_name['organization_id']._options = None
  _ROPA.fields_by_name['organization_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _PROJECTPLAN._serialized_start=198
  _PROJECTPLAN._serialized_end=319
  _FORMTEMPLATE._serialized_start=322
  _FORMTEMPLATE._serialized_end=764
  _FORMTEMPLATE_ENTRYORFORMTEMPLATEID._serialized_start=572
  _FORMTEMPLATE_ENTRYORFORMTEMPLATEID._serialized_end=764
  _FORMTEMPLATEREFERENCE._serialized_start=766
  _FORMTEMPLATEREFERENCE._serialized_end=852
  _ENTRY._serialized_start=855
  _ENTRY._serialized_end=4114
  _ENTRY_ADDONEENTRY._serialized_start=2209
  _ENTRY_ADDONEENTRY._serialized_end=2746
  _ENTRY_TASK._serialized_start=2748
  _ENTRY_TASK._serialized_end=2754
  _ENTRY_DATACONTRACT._serialized_start=2756
  _ENTRY_DATACONTRACT._serialized_end=2844
  _ENTRY_DOCUMENT._serialized_start=2846
  _ENTRY_DOCUMENT._serialized_end=2902
  _ENTRY_PIPELINE._serialized_start=2905
  _ENTRY_PIPELINE._serialized_end=3066
  _ENTRY_QUESTION._serialized_start=3069
  _ENTRY_QUESTION._serialized_end=3254
  _ENTRY_QUESTION_ANSWERANDLABEL._serialized_start=3192
  _ENTRY_QUESTION_ANSWERANDLABEL._serialized_end=3254
  _ENTRY_MULTIPLECHOICEITEM._serialized_start=3257
  _ENTRY_MULTIPLECHOICEITEM._serialized_end=3612
  _ENTRY_MULTIPLECHOICEITEM_STYLE._serialized_start=3543
  _ENTRY_MULTIPLECHOICEITEM_STYLE._serialized_end=3612
  _ENTRY_RISKASSESSMENTITEM._serialized_start=3615
  _ENTRY_RISKASSESSMENTITEM._serialized_end=3768
  _ENTRY_RISKMITIGATIONITEM._serialized_start=3771
  _ENTRY_RISKMITIGATIONITEM._serialized_end=3958
  _ENTRY_RECORDINGITEM._serialized_start=3960
  _ENTRY_RECORDINGITEM._serialized_end=4033
  _ENTRY_SECTIONOPEN._serialized_start=4035
  _ENTRY_SECTIONOPEN._serialized_end=4085
  _ENTRY_SECTIONCLOSE._serialized_start=4087
  _ENTRY_SECTIONCLOSE._serialized_end=4101
  _CONTACTDETAILS._serialized_start=4117
  _CONTACTDETAILS._serialized_end=4454
  _CONTACTDETAILS_CONTACTTYPE._serialized_start=4338
  _CONTACTDETAILS_CONTACTTYPE._serialized_end=4454
  _PARTY._serialized_start=4457
  _PARTY._serialized_end=4907
  _PARTY_LIST._serialized_start=4741
  _PARTY_LIST._serialized_end=4814
  _PARTY_RELATIONTYPE._serialized_start=4816
  _PARTY_RELATIONTYPE._serialized_end=4907
  _CATEGORY._serialized_start=4910
  _CATEGORY._serialized_end=5335
  _CATEGORY_LIST._serialized_start=5101
  _CATEGORY_LIST._serialized_end=5183
  _CATEGORY_TYPE._serialized_start=5186
  _CATEGORY_TYPE._serialized_end=5335
  _DATAASSET._serialized_start=5338
  _DATAASSET._serialized_end=5857
  _DATAASSET_LIST._serialized_start=5709
  _DATAASSET_LIST._serialized_end=5793
  _DATAASSET_RELATIONTYPE._serialized_start=5795
  _DATAASSET_RELATIONTYPE._serialized_end=5857
  _ROPA._serialized_start=5860
  _ROPA._serialized_end=7105
  _ROPA_RECORD._serialized_start=5996
  _ROPA_RECORD._serialized_end=7105
  _ROPA_RECORD_PARTIESENTRY._serialized_start=6776
  _ROPA_RECORD_PARTIESENTRY._serialized_end=6880
  _ROPA_RECORD_CATEGORIESENTRY._serialized_start=6882
  _ROPA_RECORD_CATEGORIESENTRY._serialized_end=6992
  _ROPA_RECORD_DATAASSETSENTRY._serialized_start=6994
  _ROPA_RECORD_DATAASSETSENTRY._serialized_end=7105
# @@protoc_insertion_point(module_scope)
