# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/forms/v1alpha/forms_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1alpha import entities_v1alpha_pb2 as strmprivacy_dot_api_dot_entities_dot_v1alpha_dot_entities__v1alpha__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1strmprivacy/api/forms/v1alpha/forms_v1alpha.proto\x12\x1dstrmprivacy.api.forms.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a\x37strmprivacy/api/entities/v1alpha/entities_v1alpha.proto\x1a\x17validate/validate.proto\"\x1a\n\x18ListFormTemplatesRequest\"r\n\x19ListFormTemplatesResponse\x12U\n\x0e\x66orm_templates\x18\x01 \x03(\x0b\x32..strmprivacy.api.entities.v1alpha.FormTemplateR\rformTemplates\"2\n\x16GetFormTemplateRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\"n\n\x17GetFormTemplateResponse\x12S\n\rform_template\x18\x01 \x01(\x0b\x32..strmprivacy.api.entities.v1alpha.FormTemplateR\x0c\x66ormTemplate\"u\n\x19UpsertFormTemplateRequest\x12X\n\rform_template\x18\x01 \x01(\x0b\x32..strmprivacy.api.entities.v1alpha.FormTemplateB\x03\xe0\x41\x02R\x0c\x66ormTemplate\"v\n\x1aUpsertFormTemplateResponse\x12X\n\rform_template\x18\x01 \x01(\x0b\x32..strmprivacy.api.entities.v1alpha.FormTemplateB\x03\xe0\x41\x02R\x0c\x66ormTemplate\"0\n\x19\x44\x65leteFormTemplateRequest\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\"\x1c\n\x1a\x44\x65leteFormTemplateResponse2\xb2\x04\n\x0c\x46ormsService\x12\x86\x01\n\x11ListFormTemplates\x12\x37.strmprivacy.api.forms.v1alpha.ListFormTemplatesRequest\x1a\x38.strmprivacy.api.forms.v1alpha.ListFormTemplatesResponse\x12\x80\x01\n\x0fGetFormTemplate\x12\x35.strmprivacy.api.forms.v1alpha.GetFormTemplateRequest\x1a\x36.strmprivacy.api.forms.v1alpha.GetFormTemplateResponse\x12\x89\x01\n\x12UpsertFormTemplate\x12\x38.strmprivacy.api.forms.v1alpha.UpsertFormTemplateRequest\x1a\x39.strmprivacy.api.forms.v1alpha.UpsertFormTemplateResponse\x12\x89\x01\n\x12\x44\x65leteFormTemplate\x12\x38.strmprivacy.api.forms.v1alpha.DeleteFormTemplateRequest\x1a\x39.strmprivacy.api.forms.v1alpha.DeleteFormTemplateResponseBj\n io.strmprivacy.api.forms.v1alphaP\x01ZDgithub.com/strmprivacy/api-definitions-go/v3/api/forms/v1alpha;formsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.forms.v1alpha.forms_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.strmprivacy.api.forms.v1alphaP\001ZDgithub.com/strmprivacy/api-definitions-go/v3/api/forms/v1alpha;forms'
  _GETFORMTEMPLATEREQUEST.fields_by_name['id']._options = None
  _GETFORMTEMPLATEREQUEST.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _UPSERTFORMTEMPLATEREQUEST.fields_by_name['form_template']._options = None
  _UPSERTFORMTEMPLATEREQUEST.fields_by_name['form_template']._serialized_options = b'\340A\002'
  _UPSERTFORMTEMPLATERESPONSE.fields_by_name['form_template']._options = None
  _UPSERTFORMTEMPLATERESPONSE.fields_by_name['form_template']._serialized_options = b'\340A\002'
  _DELETEFORMTEMPLATEREQUEST.fields_by_name['id']._options = None
  _DELETEFORMTEMPLATEREQUEST.fields_by_name['id']._serialized_options = b'\340A\002'
  _LISTFORMTEMPLATESREQUEST._serialized_start=199
  _LISTFORMTEMPLATESREQUEST._serialized_end=225
  _LISTFORMTEMPLATESRESPONSE._serialized_start=227
  _LISTFORMTEMPLATESRESPONSE._serialized_end=341
  _GETFORMTEMPLATEREQUEST._serialized_start=343
  _GETFORMTEMPLATEREQUEST._serialized_end=393
  _GETFORMTEMPLATERESPONSE._serialized_start=395
  _GETFORMTEMPLATERESPONSE._serialized_end=505
  _UPSERTFORMTEMPLATEREQUEST._serialized_start=507
  _UPSERTFORMTEMPLATEREQUEST._serialized_end=624
  _UPSERTFORMTEMPLATERESPONSE._serialized_start=626
  _UPSERTFORMTEMPLATERESPONSE._serialized_end=744
  _DELETEFORMTEMPLATEREQUEST._serialized_start=746
  _DELETEFORMTEMPLATEREQUEST._serialized_end=794
  _DELETEFORMTEMPLATERESPONSE._serialized_start=796
  _DELETEFORMTEMPLATERESPONSE._serialized_end=824
  _FORMSSERVICE._serialized_start=827
  _FORMSSERVICE._serialized_end=1389
# @@protoc_insertion_point(module_scope)
