# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/parties/v1alpha/parties_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1alpha import entities_v1alpha_pb2 as strmprivacy_dot_api_dot_entities_dot_v1alpha_dot_entities__v1alpha__pb2
from strmprivacy.api.paging.v1alpha import paging_v1alpha_pb2 as strmprivacy_dot_api_dot_paging_dot_v1alpha_dot_paging__v1alpha__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5strmprivacy/api/parties/v1alpha/parties_v1alpha.proto\x12\x1fstrmprivacy.api.parties.v1alpha\x1a\x37strmprivacy/api/entities/v1alpha/entities_v1alpha.proto\x1a\x33strmprivacy/api/paging/v1alpha/paging_v1alpha.proto\x1a\x17validate/validate.proto\"[\n\x12ListPartiesRequest\x12\x45\n\tpage_info\x18\x01 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\"\x9f\x01\n\x13ListPartiesResponse\x12\x41\n\x07parties\x18\x01 \x03(\x0b\x32\'.strmprivacy.api.entities.v1alpha.PartyR\x07parties\x12\x45\n\tpage_info\x18\x02 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\"+\n\x0fGetPartyRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\"Q\n\x10GetPartyResponse\x12=\n\x05party\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1alpha.PartyR\x05party\"S\n\x12UpsertPartyRequest\x12=\n\x05party\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1alpha.PartyR\x05party\"T\n\x13UpsertPartyResponse\x12=\n\x05party\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1alpha.PartyR\x05party2\xf5\x02\n\x0ePartiesService\x12x\n\x0bListParties\x12\x33.strmprivacy.api.parties.v1alpha.ListPartiesRequest\x1a\x34.strmprivacy.api.parties.v1alpha.ListPartiesResponse\x12o\n\x08GetParty\x12\x30.strmprivacy.api.parties.v1alpha.GetPartyRequest\x1a\x31.strmprivacy.api.parties.v1alpha.GetPartyResponse\x12x\n\x0bUpsertParty\x12\x33.strmprivacy.api.parties.v1alpha.UpsertPartyRequest\x1a\x34.strmprivacy.api.parties.v1alpha.UpsertPartyResponseBp\n\"io.strmprivacy.api.parties.v1alphaP\x01ZHgithub.com/strmprivacy/api-definitions-go/v3/api/parties/v1alpha;partiesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.parties.v1alpha.parties_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.strmprivacy.api.parties.v1alphaP\001ZHgithub.com/strmprivacy/api-definitions-go/v3/api/parties/v1alpha;parties'
  _GETPARTYREQUEST.fields_by_name['id']._options = None
  _GETPARTYREQUEST.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTPARTIESREQUEST._serialized_start=225
  _LISTPARTIESREQUEST._serialized_end=316
  _LISTPARTIESRESPONSE._serialized_start=319
  _LISTPARTIESRESPONSE._serialized_end=478
  _GETPARTYREQUEST._serialized_start=480
  _GETPARTYREQUEST._serialized_end=523
  _GETPARTYRESPONSE._serialized_start=525
  _GETPARTYRESPONSE._serialized_end=606
  _UPSERTPARTYREQUEST._serialized_start=608
  _UPSERTPARTYREQUEST._serialized_end=691
  _UPSERTPARTYRESPONSE._serialized_start=693
  _UPSERTPARTYRESPONSE._serialized_end=777
  _PARTIESSERVICE._serialized_start=780
  _PARTIESSERVICE._serialized_end=1153
# @@protoc_insertion_point(module_scope)
