# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/ropa/v1alpha/ropa_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from strmprivacy.api.paging.v1alpha import paging_v1alpha_pb2 as strmprivacy_dot_api_dot_paging_dot_v1alpha_dot_paging__v1alpha__pb2
from validate import validate_pb2 as validate_dot_validate__pb2
from strmprivacy.api.entities.v1alpha import entities_v1alpha_pb2 as strmprivacy_dot_api_dot_entities_dot_v1alpha_dot_entities__v1alpha__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/strmprivacy/api/ropa/v1alpha/ropa_v1alpha.proto\x12\x1cstrmprivacy.api.ropa.v1alpha\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x33strmprivacy/api/paging/v1alpha/paging_v1alpha.proto\x1a\x17validate/validate.proto\x1a\x37strmprivacy/api/entities/v1alpha/entities_v1alpha.proto\"W\n\x0eGetRopaRequest\x12\x45\n\tpage_info\x18\x01 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\"\x94\x01\n\x0fGetRopaResponse\x12:\n\x04ropa\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1alpha.RopaR\x04ropa\x12\x45\n\tpage_info\x18\x02 \x01(\x0b\x32(.strmprivacy.api.paging.v1alpha.PageInfoR\x08pageInfo\"\\\n\x13\x43reateRecordRequest\x12\x45\n\x06record\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.Ropa.RecordR\x06record\"]\n\x14\x43reateRecordResponse\x12\x45\n\x06record\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.Ropa.RecordR\x06record\"/\n\x10GetRecordRequest\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x02id\"Z\n\x11GetRecordResponse\x12\x45\n\x06record\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1alpha.Ropa.RecordR\x06record2\xda\x02\n\x0bRopaService\x12\x66\n\x07GetRopa\x12,.strmprivacy.api.ropa.v1alpha.GetRopaRequest\x1a-.strmprivacy.api.ropa.v1alpha.GetRopaResponse\x12u\n\x0c\x43reateRecord\x12\x31.strmprivacy.api.ropa.v1alpha.CreateRecordRequest\x1a\x32.strmprivacy.api.ropa.v1alpha.CreateRecordResponse\x12l\n\tGetRecord\x12..strmprivacy.api.ropa.v1alpha.GetRecordRequest\x1a/.strmprivacy.api.ropa.v1alpha.GetRecordResponseBg\n\x1fio.strmprivacy.api.ropa.v1alphaP\x01ZBgithub.com/strmprivacy/api-definitions-go/v3/api/ropa/v1alpha;ropab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.ropa.v1alpha.ropa_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.strmprivacy.api.ropa.v1alphaP\001ZBgithub.com/strmprivacy/api-definitions-go/v3/api/ropa/v1alpha;ropa'
  _GETRECORDREQUEST.fields_by_name['id']._options = None
  _GETRECORDREQUEST.fields_by_name['id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _GETROPAREQUEST._serialized_start=263
  _GETROPAREQUEST._serialized_end=350
  _GETROPARESPONSE._serialized_start=353
  _GETROPARESPONSE._serialized_end=501
  _CREATERECORDREQUEST._serialized_start=503
  _CREATERECORDREQUEST._serialized_end=595
  _CREATERECORDRESPONSE._serialized_start=597
  _CREATERECORDRESPONSE._serialized_end=690
  _GETRECORDREQUEST._serialized_start=692
  _GETRECORDREQUEST._serialized_end=739
  _GETRECORDRESPONSE._serialized_start=741
  _GETRECORDRESPONSE._serialized_end=831
  _ROPASERVICE._serialized_start=834
  _ROPASERVICE._serialized_end=1180
# @@protoc_insertion_point(module_scope)
