# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/onboarding/v1/onboarding_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1strmprivacy/api/onboarding/v1/onboarding_v1.proto\x12\x1dstrmprivacy.api.onboarding.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\x8b\x01\n PopulateOnboardingProjectRequest\x12\"\n\x06handle\x18\x01 \x01(\tB\n\xe0\x41\x02\xfa\x42\x04r\x02\x10\x04R\x06handle\x12\x43\n\x07project\x18\x02 \x01(\x0b\x32$.strmprivacy.api.entities.v1.ProjectB\x03\xe0\x41\x02R\x07project\"#\n!PopulateOnboardingProjectResponse2\xb4\x01\n\x11OnboardingService\x12\x9e\x01\n\x19PopulateOnboardingProject\x12?.strmprivacy.api.onboarding.v1.PopulateOnboardingProjectRequest\x1a@.strmprivacy.api.onboarding.v1.PopulateOnboardingProjectResponseBo\n io.strmprivacy.api.onboarding.v1P\x01ZIgithub.com/strmprivacy/api-definitions-go/v3/api/onboarding/v1;onboardingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.onboarding.v1.onboarding_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.strmprivacy.api.onboarding.v1P\001ZIgithub.com/strmprivacy/api-definitions-go/v3/api/onboarding/v1;onboarding'
  _POPULATEONBOARDINGPROJECTREQUEST.fields_by_name['handle']._options = None
  _POPULATEONBOARDINGPROJECTREQUEST.fields_by_name['handle']._serialized_options = b'\340A\002\372B\004r\002\020\004'
  _POPULATEONBOARDINGPROJECTREQUEST.fields_by_name['project']._options = None
  _POPULATEONBOARDINGPROJECTREQUEST.fields_by_name['project']._serialized_options = b'\340A\002'
  _POPULATEONBOARDINGPROJECTREQUEST._serialized_start=190
  _POPULATEONBOARDINGPROJECTREQUEST._serialized_end=329
  _POPULATEONBOARDINGPROJECTRESPONSE._serialized_start=331
  _POPULATEONBOARDINGPROJECTRESPONSE._serialized_end=366
  _ONBOARDINGSERVICE._serialized_start=369
  _ONBOARDINGSERVICE._serialized_end=549
# @@protoc_insertion_point(module_scope)
