# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/paging/v1alpha/paging_v1alpha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3strmprivacy/api/paging/v1alpha/paging_v1alpha.proto\x12\x1estrmprivacy.api.paging.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\"\xe4\x01\n\x08PageInfo\x12\x1b\n\tpage_size\x18\x01 \x01(\x05R\x08pageSize\x12\"\n\ntotal_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x03R\ttotalSize\x12&\n\x0c\x63urrent_page\x18\x03 \x01(\x05\x42\x03\xe0\x41\x03R\x0b\x63urrentPage\x12%\n\x0erequested_page\x18\x04 \x01(\x05R\rrequestedPage\x12$\n\x0btotal_pages\x18\x05 \x01(\x05\x42\x03\xe0\x41\x03R\ntotalPages\x12\"\n\npage_token\x18\x06 \x01(\tB\x03\xe0\x41\x03R\tpageTokenBm\n!io.strmprivacy.api.paging.v1alphaP\x01ZFgithub.com/strmprivacy/api-definitions-go/v3/api/paging/v1alpha;pagingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.paging.v1alpha.paging_v1alpha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.paging.v1alphaP\001ZFgithub.com/strmprivacy/api-definitions-go/v3/api/paging/v1alpha;paging'
  _PAGEINFO.fields_by_name['total_size']._options = None
  _PAGEINFO.fields_by_name['total_size']._serialized_options = b'\340A\003'
  _PAGEINFO.fields_by_name['current_page']._options = None
  _PAGEINFO.fields_by_name['current_page']._serialized_options = b'\340A\003'
  _PAGEINFO.fields_by_name['total_pages']._options = None
  _PAGEINFO.fields_by_name['total_pages']._serialized_options = b'\340A\003'
  _PAGEINFO.fields_by_name['page_token']._options = None
  _PAGEINFO.fields_by_name['page_token']._serialized_options = b'\340A\003'
  _PAGEINFO._serialized_start=121
  _PAGEINFO._serialized_end=349
# @@protoc_insertion_point(module_scope)
