# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.forms.v1alpha import forms_v1alpha_pb2 as strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2


class FormsServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListFormTemplates = channel.unary_unary(
                '/strmprivacy.api.forms.v1alpha.FormsService/ListFormTemplates',
                request_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.ListFormTemplatesRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.ListFormTemplatesResponse.FromString,
                )
        self.GetFormTemplate = channel.unary_unary(
                '/strmprivacy.api.forms.v1alpha.FormsService/GetFormTemplate',
                request_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.GetFormTemplateRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.GetFormTemplateResponse.FromString,
                )
        self.UpsertFormTemplate = channel.unary_unary(
                '/strmprivacy.api.forms.v1alpha.FormsService/UpsertFormTemplate',
                request_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.UpsertFormTemplateRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.UpsertFormTemplateResponse.FromString,
                )
        self.DeleteFormTemplate = channel.unary_unary(
                '/strmprivacy.api.forms.v1alpha.FormsService/DeleteFormTemplate',
                request_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.DeleteFormTemplateRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.DeleteFormTemplateResponse.FromString,
                )


class FormsServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListFormTemplates(self, request, context):
        """CRUD on Form Templates
        returns all the form templates for the organization of the caller.
        currently also includes the hard-coded templates
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFormTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertFormTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFormTemplate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FormsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListFormTemplates': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFormTemplates,
                    request_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.ListFormTemplatesRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.ListFormTemplatesResponse.SerializeToString,
            ),
            'GetFormTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFormTemplate,
                    request_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.GetFormTemplateRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.GetFormTemplateResponse.SerializeToString,
            ),
            'UpsertFormTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertFormTemplate,
                    request_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.UpsertFormTemplateRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.UpsertFormTemplateResponse.SerializeToString,
            ),
            'DeleteFormTemplate': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFormTemplate,
                    request_deserializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.DeleteFormTemplateRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.DeleteFormTemplateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.forms.v1alpha.FormsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FormsService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListFormTemplates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.forms.v1alpha.FormsService/ListFormTemplates',
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.ListFormTemplatesRequest.SerializeToString,
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.ListFormTemplatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFormTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.forms.v1alpha.FormsService/GetFormTemplate',
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.GetFormTemplateRequest.SerializeToString,
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.GetFormTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpsertFormTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.forms.v1alpha.FormsService/UpsertFormTemplate',
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.UpsertFormTemplateRequest.SerializeToString,
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.UpsertFormTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFormTemplate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.forms.v1alpha.FormsService/DeleteFormTemplate',
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.DeleteFormTemplateRequest.SerializeToString,
            strmprivacy_dot_api_dot_forms_dot_v1alpha_dot_forms__v1alpha__pb2.DeleteFormTemplateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
