# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strmprivacy.api.project_plans.v1alpha import project_plans_v1alpha_pb2 as strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2


class ProjectPlansServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListProjectPlans = channel.unary_unary(
                '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/ListProjectPlans',
                request_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.ListProjectPlansRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.ListProjectPlansResponse.FromString,
                )
        self.GetProjectPlan = channel.unary_unary(
                '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/GetProjectPlan',
                request_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.GetProjectPlanRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.GetProjectPlanResponse.FromString,
                )
        self.UpsertProjectPlan = channel.unary_unary(
                '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/UpsertProjectPlan',
                request_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.UpsertProjectPlanRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.UpsertProjectPlanResponse.FromString,
                )
        self.DeleteProjectPlan = channel.unary_unary(
                '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/DeleteProjectPlan',
                request_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.DeleteProjectPlanRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.DeleteProjectPlanResponse.FromString,
                )
        self.BuildProjectPlan = channel.unary_unary(
                '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/BuildProjectPlan',
                request_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanResponse.FromString,
                )
        self.BuildProjectPlanFromTemplateIds = channel.unary_unary(
                '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/BuildProjectPlanFromTemplateIds',
                request_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanFromTemplateIdsRequest.SerializeToString,
                response_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanFromTemplateIdsResponse.FromString,
                )


class ProjectPlansServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListProjectPlans(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProjectPlan(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpsertProjectPlan(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteProjectPlan(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BuildProjectPlan(self, request, context):
        """builds an empty (not filled-in) project plan from a template and store it in the database.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BuildProjectPlanFromTemplateIds(self, request, context):
        """builds an empty (not filled-in) project plan from a template and store it in the database.
        (-- api-linter: core::0136::prepositions=disabled
        aip.dev/not-precedent: We need to do this because the name makes sense. --)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectPlansServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListProjectPlans': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProjectPlans,
                    request_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.ListProjectPlansRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.ListProjectPlansResponse.SerializeToString,
            ),
            'GetProjectPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProjectPlan,
                    request_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.GetProjectPlanRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.GetProjectPlanResponse.SerializeToString,
            ),
            'UpsertProjectPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.UpsertProjectPlan,
                    request_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.UpsertProjectPlanRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.UpsertProjectPlanResponse.SerializeToString,
            ),
            'DeleteProjectPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteProjectPlan,
                    request_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.DeleteProjectPlanRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.DeleteProjectPlanResponse.SerializeToString,
            ),
            'BuildProjectPlan': grpc.unary_unary_rpc_method_handler(
                    servicer.BuildProjectPlan,
                    request_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanResponse.SerializeToString,
            ),
            'BuildProjectPlanFromTemplateIds': grpc.unary_unary_rpc_method_handler(
                    servicer.BuildProjectPlanFromTemplateIds,
                    request_deserializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanFromTemplateIdsRequest.FromString,
                    response_serializer=strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanFromTemplateIdsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strmprivacy.api.project_plans.v1alpha.ProjectPlansService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ProjectPlansService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListProjectPlans(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/ListProjectPlans',
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.ListProjectPlansRequest.SerializeToString,
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.ListProjectPlansResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProjectPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/GetProjectPlan',
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.GetProjectPlanRequest.SerializeToString,
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.GetProjectPlanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpsertProjectPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/UpsertProjectPlan',
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.UpsertProjectPlanRequest.SerializeToString,
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.UpsertProjectPlanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteProjectPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/DeleteProjectPlan',
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.DeleteProjectPlanRequest.SerializeToString,
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.DeleteProjectPlanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BuildProjectPlan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/BuildProjectPlan',
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanRequest.SerializeToString,
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BuildProjectPlanFromTemplateIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strmprivacy.api.project_plans.v1alpha.ProjectPlansService/BuildProjectPlanFromTemplateIds',
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanFromTemplateIdsRequest.SerializeToString,
            strmprivacy_dot_api_dot_project__plans_dot_v1alpha_dot_project__plans__v1alpha__pb2.BuildProjectPlanFromTemplateIdsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
